==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/et/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Kasutaja on veebisaidil tühistanud üksuse taotluse',
    'a_user_requested' => 'Kasutaja on taotlenud üksuse veebisaidil',
    'accessory_name' => 'Lisaseade Nimi:',
    'additional_notes' => 'Lisamärkmed:',
    'admin_has_created' => 'Administraator on loonud konto teile: veebisaidil.',
    'asset' => 'Vahend:',
    'asset_name' => 'Vahendi nimi:',
    'asset_requested' => 'Vara nõutud',
    'asset_tag' => 'Vara silt:',
    'assigned_to' => 'Määratud',
    'best_regards' => 'Parimate soovidega,',
    'canceled' => 'Tühistatud:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Kinnitamiseks klõpsake järgmisel lingil: veebikonto:',
    'click_on_the_link_accessory' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete lisaseadme kätte saanud.',
    'click_on_the_link_asset' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete vara vastu võtnud.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Praegune QTY',
    'Days' => 'Päeva',
    'days' => 'Päeva',
    'expecting_checkin_date' => 'Ootel Checkin Kuupäev:',
    'expires' => 'Aegub',
    'Expiring_Assets_Report' => 'Aeguvate varade aruanne.',
    'Expiring_Licenses_Report' => 'Aeguvad litsentside aruanne.',
    'hello' => 'Tere',
    'hi' => 'Tere',
    'i_have_read' => 'Olen lugenud ja nõustun kasutustingimustega ja saanud selle kirje.',
    'item' => 'Kirje:',
    'Item_Request_Canceled' => 'Üksuse taotlus tühistatud',
    'Item_Requested' => 'Taotletud üksus',
    'link_to_update_password' => 'Klienditeenuse uuendamiseks klõpsake järgmisel lingil:',
    'login_first_admin' => 'Logige oma uude Snipe-IT-seadmesse sisse, kasutades allpool toodud mandaate.',
    'login' => 'Logi sisse:',
    'Low_Inventory_Report' => 'Madal inventuuriaruanne',
    'min_QTY' => 'Min QTY',
    'name' => 'Nimi',
    'new_item_checked' => 'Uue elemendi on teie nime all kontrollitud, üksikasjad on allpool.',
    'password' => 'Parool:',
    'password_reset' => 'Parooli taastamine',

    'read_the_terms' => 'Palun lugege allpool toodud kasutustingimused.',
    'read_the_terms_and_click' => 'Palun lugege allpool toodud kasutustingimused ja klõpsake alloleval lingil, et kinnitada, et lugesite ja nõustute kasutustingimustega ning olete vara saanud.',
    'requested' => 'Taotletud:',
    'reset_link' => 'Teie salasõna lähtestamise link',
    'reset_password' => 'Parooli lähtestamiseks klõpsake siin:',
    'serial' => 'Seerianumber',
    'supplier' => 'Tarnija',
    'tag' => 'Silt',
    'test_email' => 'Test Snipe-IT-i e-posti teel',
    'test_mail_text' => 'See on Snipe-IT-i varahaldussüsteemi test. Kui sul on see, töötab post. :)',
    'the_following_item' => 'Järgmine element on kontrollitud:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Selleks, et lähtestada oma: veebiparool, täitke see vorm:',
    'type' => 'Tüüp',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Kasutaja',
    'username' => 'Kasutajanimi',
    'welcome' => 'Tere tulemast, :name',
    'welcome_to' => 'Teretulemast lehele :web!',
    'your_credentials' => 'Sinu Snipe-IT rekvisiidid',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/et/mail.php <==
<?php

return [
    'a_user_canceled' => 'Kasutaja on veebisaidil tühistanud üksuse taotluse',
    'a_user_requested' => 'Kasutaja on taotlenud üksuse veebisaidil',
    'accessory_name' => 'Lisaseade Nimi:',
    'additional_notes' => 'Lisamärkmed:',
    'admin_has_created' => 'Administraator on loonud konto teile: veebisaidil.',
    'asset' => 'Vahend:',
    'asset_name' => 'Vahendi nimi:',
    'asset_requested' => 'Vara nõutud',
    'asset_tag' => 'Varade silt',
    'assigned_to' => 'Määratud',
    'best_regards' => 'Parimate soovidega,',
    'canceled' => 'Tühistatud:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Kinnitamiseks klõpsake järgmisel lingil: veebikonto:',
    'click_on_the_link_accessory' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete lisaseadme kätte saanud.',
    'click_on_the_link_asset' => 'Klõpsake allosas oleval lingil, et kinnitada, et olete vara vastu võtnud.',
    'Confirm_Asset_Checkin' => 'Vara sissevõtmise kinnitus',
    'Confirm_Accessory_Checkin' => 'Tarvitu sissevõtmise kinnitus',
    'Confirm_accessory_delivery' => 'Tarvitu tarne kinnitus',
    'Confirm_license_delivery' => 'Litsentsi tarne kinnitus',
    'Confirm_asset_delivery' => 'Vara tarne kinnitus',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Praegune QTY',
    'Days' => 'Päeva',
    'days' => 'Päeva',
    'expecting_checkin_date' => 'Ootel Checkin Kuupäev:',
    'expires' => 'Aegub',
    'Expiring_Assets_Report' => 'Aeguvate varade aruanne.',
    'Expiring_Licenses_Report' => 'Aeguvad litsentside aruanne.',
    'hello' => 'Tere',
    'hi' => 'Tere',
    'i_have_read' => 'Olen lugenud ja nõustun kasutustingimustega ja saanud selle kirje.',
    'item' => 'Kirje:',
    'Item_Request_Canceled' => 'Üksuse taotlus tühistatud',
    'Item_Requested' => 'Taotletud üksus',
    'link_to_update_password' => 'Klienditeenuse uuendamiseks klõpsake järgmisel lingil:',
    'login_first_admin' => 'Logige oma uude Snipe-IT-seadmesse sisse, kasutades allpool toodud mandaate.',
    'login' => 'Logi sisse:',
    'Low_Inventory_Report' => 'Madal inventuuriaruanne',
    'min_QTY' => 'Min QTY',
    'name' => 'Nimi',
    'new_item_checked' => 'Uue elemendi on teie nime all kontrollitud, üksikasjad on allpool.',
    'password' => 'Parool:',
    'password_reset' => 'Parooli taastamine',

    'read_the_terms' => 'Palun lugege allpool toodud kasutustingimused.',
    'read_the_terms_and_click' => 'Palun lugege allpool toodud kasutustingimused ja klõpsake alloleval lingil, et kinnitada, et lugesite ja nõustute kasutustingimustega ning olete vara saanud.',
    'requested' => 'Taotletud:',
    'reset_link' => 'Teie salasõna lähtestamise link',
    'reset_password' => 'Parooli lähtestamiseks klõpsake siin:',
    'serial' => 'Seerianumber',
    'supplier' => 'Tarnija',
    'tag' => 'Silt',
    'test_email' => 'Test Snipe-IT-i e-posti teel',
    'test_mail_text' => 'See on Snipe-IT-i varahaldussüsteemi test. Kui sul on see, töötab post. :)',
    'the_following_item' => 'Järgmine element on kontrollitud:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Selleks, et lähtestada oma: veebiparool, täitke see vorm:',
    'type' => 'Tüüp',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Kasutaja',
    'username' => 'Kasutajanimi',
    'welcome' => 'Tere tulemast, :name',
    'welcome_to' => 'Teretulemast lehele :web!',
    'your_credentials' => 'Sinu Snipe-IT rekvisiidid',
    'Accessory_Checkin_Notification' => 'Tarvikud sisse võetud',
    'Asset_Checkin_Notification' => 'Vara sissevõetud',
    'License_Checkin_Notification' => 'Litsents sisse võetud',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Vaata oma varasi',
];
